@@ -145,6 +145,8 @@ def write_file(home, file_name, value):
 
 def check_whatap_home(target='WHATAP_HOME'):
     whatap_home = os.environ.get(target)
+    if not whatap_home:
+        whatap_home = find_whatap_conf()
     if not whatap_home:
         whatap_print('WHATAP: ${} is empty'.format(target))
     
@@ -153,6 +155,8 @@ def check_whatap_home(target='WHATAP_HOME'):
 
 def init_config(home):
     whatap_home = os.environ.get(home)
+    if not whatap_home:
+        whatap_home = find_whatap_conf()
     if not whatap_home:
         whatap_home = read_file(home, home.lower())
         if not whatap_home:
@@ -555,4 +559,25 @@ def configPort():
     port = get_port_number()
     if port:
         update_config('WHATAP_HOME', 'net_udp_port', str(port))
-        return port
\ No newline at end of file
+        return port
+
+
+def find_whatap_conf():
+    # 1. 현재 디렉토리 검색
+    script_dir = os.path.dirname(os.path.abspath(__file__))
+    parent_dir = os.path.dirname(script_dir)
+    conf_path = os.path.join(parent_dir, 'whatap.conf')
+    if os.path.exists(conf_path):
+        os.environ['WHATAP_HOME'] = parent_dir
+        return conf_path
+
+    # 2. 상위 디렉토리들 검색
+    current = parent_dir
+    while current != '/':
+        conf_path = os.path.join(current, 'whatap.conf')
+        if os.path.exists(conf_path):
+            os.environ['WHATAP_HOME'] = current
+            return conf_path
+        current = os.path.dirname(current)
+
+    return None
\ No newline at end of file
