@@ -6,7 +6,9 @@ Configuration = {
     "trace_user_enabled": True,
     "trace_user_using_ip": True,
     "trace_logging_enabled": False,
+    "trace_logging_mtid_enabled": False,
     "trace_loguru_enabled": False,
+    "trace_loguru_mtid_enabled": False,
     "trace_ignore_url_set": [],
     "trace_ignore_url_prefix": None,
 
