@@ -65,9 +65,7 @@ def trace_handler(fn, start=False, preload=None):
                 if ctx and ctx.error_step == e:
                     ctx.error_step = None
                     raise e
-                logging.debug(e, extra={'id': 'WA917'}, exc_info=True)
-                print(e, dict(extra={'id': 'WA917'}, exc_info=True))
-                return fn(*args, **kwargs)
+                raise
             else:
                 if ctx and ctx.error_step:
                     e = ctx.error_step
@@ -157,8 +155,6 @@ def interceptor(rn_environ, *args, **kwargs):
     ctx.userAgentString = environ.get('HTTP_USER_AGENT', '')
     ctx.referer = environ.get('HTTP_REFERER', '')
 
-
-
     if conf.trace_user_enabled:
         if conf.trace_user_using_ip:
             ctx.userid = userid_util.getRemoteAddr(args)
@@ -223,7 +219,7 @@ def interceptor(rn_environ, *args, **kwargs):
             text = ''
             for key in keys:
                 text += '{}={}\n'.format(key.split('HTTP_')[1].lower(),
-                                            environ[key])
+                                         environ[key])
 
             datas = ['HTTP-HEADERS', 'HTTP-HEADERS', text]
             ctx.start_time = DateUtil.nowSystem()
@@ -232,7 +228,8 @@ def interceptor(rn_environ, *args, **kwargs):
     finally:
         end_interceptor(ctx=ctx)
 
-def interceptor_error(status_code, errors, ctx = None):
+
+def interceptor_error(status_code, errors, ctx=None):
     if not ctx:
         ctx = TraceContextManager.getLocalContext()
     if not ctx:
@@ -274,10 +271,8 @@ def interceptor_step_error(e, ctx=None):
     errors = []
     errors.append(e.__class__.__name__)
 
-    if e.args:
-        errors.append(str(e.args[0]))
-    elif hasattr(e, "detail"):
-        errors.append(getattr(e, "detail"))
+    error_message = extract_db_error_message(e)
+    errors.append(error_message)
 
     error = ''
     frame = sys._current_frames().get(ctx.thread.ident)
@@ -294,7 +289,6 @@ def interceptor_step_error(e, ctx=None):
         error += '{} ({}:{})\n'.format(method_name, line, line_num)
 
     errors.append(error)
-    # errors.append(''.join(traceback.format_list(traceback.extract_stack(sys._current_frames()[ctx.thread.ident]))))
     async_sender.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
 
     if conf.profile_exception_stack:
@@ -304,6 +298,27 @@ def interceptor_step_error(e, ctx=None):
         async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
 
+def extract_db_error_message(e):
+    try:
+        # PostgreSQL (psycopg2)
+        if hasattr(e, 'pgcode') and hasattr(e, 'pgerror'):
+            return str(e.pgerror)
+
+        # MySQL (PyMySQL, mysql-connector-python)
+        if hasattr(e, 'args') and len(e.args) > 1 and isinstance(e.args[1], str):
+            return e.args[1]
+
+        # 기본 에러 메시지
+        if hasattr(e, 'args') and len(e.args) > 0:
+            if isinstance(e.args[0], str):
+                return e.args[0]
+            return str(e.args[0])
+
+        return str(e)
+    except:
+        return "Unknown database error"
+
+
 def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
     if not ctx or ctx.active_httpc_hash:
@@ -311,7 +326,7 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
             return fn(*args, **kwargs)
         except Exception as e:
             interceptor_step_error(e, ctx=ctx)
-        finally:    
+        finally:
             return
     param = None
     method = None
@@ -387,7 +402,7 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     text = '{}://'.format(db_type)
     text += kwargs.get('user')
     text += "@"
-    text += kwargs.get('host',kwargs.get('dsn','') )
+    text += kwargs.get('host', kwargs.get('dsn', ''))
     text += '/'
     text += kwargs.get('database', kwargs.get('db', kwargs.get('dbname', '')))
     ctx.active_dbc = text
@@ -485,7 +500,7 @@ def interceptor_db_close(fn, *args, **kwargs):
             return
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
-    
+
     try:
         callback = fn(*args, **kwargs)
         return callback
@@ -496,7 +511,7 @@ def interceptor_db_close(fn, *args, **kwargs):
         datas = [' ', ' ', text]
         ctx.elapsed = DateUtil.nowSystem() - start_time
         async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-    
+
 
 check_seq = 1
 
